@@ -1,9 +1,9 @@
 /*
  * LinuxNetworkFunctions.h - declaration of LinuxNetworkFunctions class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef LINUX_NETWORK_FUNCTIONS_H
-#define LINUX_NETWORK_FUNCTIONS_H
+#pragma once
 
 #include "PlatformNetworkFunctions.h"
 
@@ -32,11 +31,9 @@
 class LinuxNetworkFunctions : public PlatformNetworkFunctions
 {
 public:
-	bool ping( const QString& hostAddress ) override;
+	PingResult ping(const QString& hostAddress) override;
 	bool configureFirewallException( const QString& applicationPath, const QString& description, bool enabled ) override;
 
-	bool configureSocketKeepalive( int socket, bool enabled, int idleTime, int interval, int probes ) override;
+	bool configureSocketKeepalive( Socket socket, bool enabled, int idleTime, int interval, int probes ) override;
 
 };
-
-#endif // LINUX_NETWORK_FUNCTIONS_H
